@@ -1,20 +1,10 @@
 from music21 import *
 import music21 as m21
 import time
-import requests
+# import requests
+# httpx appears to be faster than requests, will fit better with an async version
+import httpx
 from pathlib import Path
-import xml.etree.ElementTree as ET
-
-# MEINSURI = 'http://www.music-encoding.org/ns/mei'
-# MEINS = '{%s}' % MEINSURI
-# mei_doc = ET.fromstring(requests.get(path).text)
-#   # Find the title from the MEI file and update the Music21 Score metadata
-# title = mei_doc.find(f'{MEINS}meiHead//{MEINS}titleStmt/{MEINS}title').text
-# score.metadata.title = title
-# mei_doc = ET.fromstring(requests.get(path).text)
-#   # Find the composer from the MEI file and update the Music21 Score metadata
-# composer = mei_doc.find(f'{MEINS}meiHead//{MEINS}respStmt/{MEINS}persName').text
-# score.metadata.composer = composer
 
 # An extension of the music21 note class with more information easily accessible
 class NoteListElement:
@@ -101,7 +91,8 @@ class CorpusBase:
             else:
                 print("Requesting file from " + str(path) + "...")
                 try:
-                    self.scores.append(m21.converter.parse(requests.get(path).text))
+                    # self.scores.append(m21.converter.parse(requests.get(path).text))
+                    self.scores.append(m21.converter.parse(httpx.get(path).text))
                     print("Successfully imported.")
                 except:
                     print("Import from " + str(path) + " failed, please check your url. File paths must begin with a '/'. Continuing to next file...")
@@ -273,7 +264,8 @@ class ScoreBase:
                 raise Exception("Import from " + str(self.url) + " failed, please check your ath/file type")
         else:
             try:
-                self.score = m21.converter.parse(requests.get(self.url).text)
+                # self.score = m21.converter.parse(requests.get(self.url).text)
+                self.score = m21.converter.parse(httpx.get(self.url).text)
                 print("Successfully imported.")
             except:
                 raise Exception("Import from " + str(self.url) + " failed, please check your url/file type")
@@ -713,8 +705,7 @@ class ClassifiedMatch:
         except:
             self.ema_url = "File must be a crim url (not a file path) to have a valid EMA url"
 
-# Potential redesign needed due to unstable nature of having user give over patterns_data
-# Potential fix is reincorporating into_patterns back into this method
+# End objects, begin methods
 def find_exact_matches(patterns_data, min_matches=5):
     """Takes in a series of vector patterns with data attached and finds exact matches
 
@@ -1051,7 +1042,8 @@ def compare_durations(durations1, durations2, threshold):
         total += abs(durations1[i]-durations2[i])
         durations1_sum += durations1[i]
         durations2_sum += durations2[i]
-    if total <= threshold or durations1_sum == durations2_sum:
+    # if total <= threshold or durations1_sum == durations2_sum:
+    if total <= threshold:
         return True
     else:
         return False
@@ -1085,7 +1077,6 @@ def classify_matches(exact_matches: list, durations_threshold = 2):
         classified_tuple[0] : list of lists of Match objects
             list of fuga, which are lists of Match objects
     """
-    # TO-DO: add in factoring for durations, narrow 80 beats window
     classified_matches = []
     for list_matches in exact_matches:
         offset_difs, offset_difs_info = [], []
@@ -1097,7 +1088,7 @@ def classify_matches(exact_matches: list, durations_threshold = 2):
                 offset_difs_info.append((match_instance[index], match_instance[index + 1]))
         i = 0
         while i < len(offset_difs) - 2:
-            if offset_difs[i] > 64 or offset_difs[i + 1] > 64:
+            if offset_difs[i] > 64 or offset_difs[i + 1] > 64 or abs(offset_difs_info[i][1].last_note.note.measureNumber - offset_difs_info[i + 1][0].first_note.note.measureNumber) > 8:
                 pass
             elif offset_difs[i] == offset_difs[i + 1] and offset_difs[i] == offset_difs[i + 2]:
                 grouping = (offset_difs_info[i][0], offset_difs_info[i][1], offset_difs_info[i + 1][0], offset_difs_info[i + 1][1], offset_difs_info[i + 2][0], offset_difs_info[i + 2][1])
@@ -1141,7 +1132,11 @@ def export_pandas(matches):
               "piece_title": match.first_note.metadata.title,
               "part": match.first_note.part,
               "start_measure": match.first_note.note.measureNumber,
+              "start_beat": match.first_note.note.beat,
               "end_measure": match.last_note.note.measureNumber,
+              "end_beat": match.last_note.note.beat,
+              "start_offset": match.first_note.offset,
+              "end_offset": match.last_note.offset,
               "note_durations": match.durations,
               "ema": match.ema,
               "ema_url": match.ema_url
